aboutsummaryrefslogtreecommitdiff
path: root/src/main/java/at/gv/egiz/pdfas/impl/api/commons
diff options
context:
space:
mode:
authortknall <tknall@7b5415b0-85f9-ee4d-85bd-d5d0c3b42d1c>2010-10-07 12:06:47 +0000
committertknall <tknall@7b5415b0-85f9-ee4d-85bd-d5d0c3b42d1c>2010-10-07 12:06:47 +0000
commit7c5cc8940f91412ceccf456672d9d41860d877d2 (patch)
treeb030fd8a4a901d845ed73cb5d5be2f21cd03aa1e /src/main/java/at/gv/egiz/pdfas/impl/api/commons
parent2bff3a44c617a330af57f5c590b52e83b37e1427 (diff)
downloadpdf-as-3-7c5cc8940f91412ceccf456672d9d41860d877d2.tar.gz
pdf-as-3-7c5cc8940f91412ceccf456672d9d41860d877d2.tar.bz2
pdf-as-3-7c5cc8940f91412ceccf456672d9d41860d877d2.zip
Provide profile description via API call.
More logging. WebApp: Bugfix for IE9 (download Link accessed twice) WebApp: Prevent Set-Cookie to be sent to BKU WebApp: Statistical logging added git-svn-id: https://joinup.ec.europa.eu/svn/pdf-as/trunk@592 7b5415b0-85f9-ee4d-85bd-d5d0c3b42d1c
Diffstat (limited to 'src/main/java/at/gv/egiz/pdfas/impl/api/commons')
-rw-r--r--src/main/java/at/gv/egiz/pdfas/impl/api/commons/SignatureProfileImpl.java48
1 files changed, 40 insertions, 8 deletions
diff --git a/src/main/java/at/gv/egiz/pdfas/impl/api/commons/SignatureProfileImpl.java b/src/main/java/at/gv/egiz/pdfas/impl/api/commons/SignatureProfileImpl.java
index fb78564..90e2ca0 100644
--- a/src/main/java/at/gv/egiz/pdfas/impl/api/commons/SignatureProfileImpl.java
+++ b/src/main/java/at/gv/egiz/pdfas/impl/api/commons/SignatureProfileImpl.java
@@ -5,6 +5,8 @@ package at.gv.egiz.pdfas.impl.api.commons;
import java.util.Properties;
+import org.apache.commons.lang.builder.ToStringBuilder;
+
import at.gv.egiz.pdfas.api.commons.SignatureProfile;
/**
@@ -24,15 +26,16 @@ public class SignatureProfileImpl implements SignatureProfile {
*/
protected String moaKeyIdentifier = null;
- // start - added by tknall
-
/**
* Properties containing the layout settings relevant to the search algorithm
* for signature blocks.
*/
protected Properties signatureBlockEntries;
-
- // stop - added by tknall
+
+ /**
+ * Short description of the profile.
+ */
+ protected String profileDescription;
/**
* Constructor.
@@ -40,13 +43,30 @@ public class SignatureProfileImpl implements SignatureProfile {
* @param profileId
* The profile identifier.
* @param moaKeyIdentifier
* The MOA key identifiert of this profile.
*/
public SignatureProfileImpl(String profileId, String moaKeyIdentifier) {
this.profileId = profileId;
this.moaKeyIdentifier = moaKeyIdentifier;
this.signatureBlockEntries = new Properties();
}
+
+ /**
+ * Constructor.
+ *
+ * @param profileId
+ * The profile identifier.
+ * @param profileDescription
+ * The profile description.
+ * @param moaKeyIdentifier
+ * The MOA key identifier of this profile.
+ */
+ public SignatureProfileImpl(String profileId, String profileDescription, String moaKeyIdentifier) {
+ this.profileId = profileId;
+ this.moaKeyIdentifier = moaKeyIdentifier;
+ this.profileDescription = profileDescription;
+ this.signatureBlockEntries = new Properties();
+ }
/**
* @see at.gv.egiz.pdfas.api.commons.SignatureProfile#getProfileId()
@@ -62,8 +82,6 @@ public class SignatureProfileImpl implements SignatureProfile {
return this.moaKeyIdentifier;
}
- // start - added by tknall
-
/**
* @see at.gv.egiz.pdfas.api.commons.SignatureProfile#getSignatureBlockEntries()
*/
@@ -86,7 +104,21 @@ public class SignatureProfileImpl implements SignatureProfile {
public void setSignatureBlockEntries(Properties signatureBlockEntries) {
this.signatureBlockEntries = signatureBlockEntries;
}
+
+ /**
+ * Returns the profile description.
+ * @return The profile description.
+ */
+ public String getProfileDescription() {
+ return this.profileDescription;
+ }
- // stop - added by tknall
+ public String toString() {
+ return new ToStringBuilder(this)
+ .append("profileId", this.profileId)
+ .append("profileDescription", this.profileDescription)
+ .append("moaKeyIdentifier", this.moaKeyIdentifier)
+ .toString();
+ }
}
@@ -40,13 +43,30 @@ public class SignatureProfileImpl implements SignatureProfile {
* The profile identifier.
* @param moaKeyIdentifier
- * The MOA key identifiert of this profile.
+ * The MOA key identifier of this profile.
*/
public SignatureProfileImpl(String profileId, String moaKeyIdentifier) {